Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1590)

Unified Diff: third_party/WebKit/Source/core/editing/SelectionEditor.h

Issue 1675163002: Rename ComposedTree to FlatTree (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: wip Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/editing/SelectionEditor.h
diff --git a/third_party/WebKit/Source/core/editing/SelectionEditor.h b/third_party/WebKit/Source/core/editing/SelectionEditor.h
index bf37ddfc81405ddf29bbfdb3ffcdaa28b53ef5f7..2a2dab491a5da2821fc959d3b8be7d4e3668d00d 100644
--- a/third_party/WebKit/Source/core/editing/SelectionEditor.h
+++ b/third_party/WebKit/Source/core/editing/SelectionEditor.h
@@ -59,7 +59,7 @@ public:
template <typename Strategy>
const VisibleSelectionTemplate<Strategy>& visibleSelection() const;
void setVisibleSelection(const VisibleSelection&, FrameSelection::SetSelectionOptions);
- void setVisibleSelection(const VisibleSelectionInComposedTree&, FrameSelection::SetSelectionOptions);
+ void setVisibleSelection(const VisibleSelectionInFlatTree&, FrameSelection::SetSelectionOptions);
void setIsDirectional(bool);
void setWithoutValidation(const Position& base, const Position& extent);
@@ -76,7 +76,7 @@ public:
// VisibleSelectionChangeObserver interface.
void didChangeVisibleSelection() override;
// Updates |m_selection| and |m_selectionInComposedTree| with up-to-date
// layout if needed.
void updateIfNeeded();
@@ -90,7 +90,7 @@ private:
LocalFrame* frame() const;
- void adjustVisibleSelectionInComposedTree();
+ void adjustVisibleSelectionInFlatTree();
void adjustVisibleSelectionInDOMTree();
TextDirection directionOfEnclosingBlock();
@@ -120,7 +120,7 @@ private:
LayoutUnit m_xPosForVerticalArrowNavigation;
VisibleSelection m_selection;
- VisibleSelectionInComposedTree m_selectionInComposedTree;
+ VisibleSelectionInFlatTree m_selectionInFlatTree;
bool m_observingVisibleSelection;
// The range specified by the user, which may not be visually canonicalized
@@ -76,7 +76,7 @@ public:
// VisibleSelectionChangeObserver interface.
void didChangeVisibleSelection() override;
- // Updates |m_selection| and |m_selectionInComposedTree| with up-to-date
+ // Updates |m_selection| and |m_selectionInFlatTree| with up-to-date
// layout if needed.
void updateIfNeeded();

Powered by Google App Engine
This is Rietveld 408576698